<h3>antimait</h3>


antimait is a library made of tools to ease the implementation 
of IoT automation systems based on devices such as Arduino and ESP.

To install it run:

<code>pip3 install antimait</code>

or clone this repository, change directory to the root of the project and run:

<code>pip3 install .</code>

<h3>Documentation</h3>

Documentation for the antimait library can be found in the <b>docs</b> directory or at the following link:
https://antimait.github.io/antimait

<h4>[ita]</h4>

antimait è una libreria composta da strumenti che possono essere utilizzati per semplificare l'implementazione 
di progetti basati su Arduino ed Esp nel campo dell'IoT.

Per installarla, basterà eseguire:

<code>pip3 install antimait</code>

o clonare questa repository, spostarsi nella cartella base del progetto ed eseguire:

<code>pip3 install .</code>

<h3>Documentazione</h3>

La documentazione relativa ad antimait (in lingua inglese) può essere trivata nella cartella <b>docs</b> o al seguente 
link:

https://antimait.github.io/antimait
